# ralf
## Using this template:
1. Run `start_project.py`, which will gather some info and rename everything.
2. Add tests.
3. Add your source code to your source directory.
4. Add your requirements to `./requirements.txt`.
5. Curate examples as python notebooks and add them to `./examples/`.
6. Replace `./ralf_logo.png` with your logo.
7. Delete this line and everything above it, as well as `start_project.py`.

<h1 align="center">BlankPythonProject</h1> 
<h3 align="center">Rotation Angle Limit Finder</h3>

<p align="center">  
  <img alt="ralflogo" src="https://github.com/JacksonBurns/ralf/blob/main/ralf_logo.png">
</p> 
<p align="center">
  <img alt="GitHub Repo Stars" src="https://img.shields.io/github/stars/JacksonBurns/ralf?style=social">
  <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/ralf">
  <img alt="PyPI" src="https://img.shields.io/pypi/v/ralf">
  <img alt="PyPI - License" src="https://img.shields.io/github/license/JacksonBurns/ralf">
</p>

## Online Documentation
[Click here to read the documentation](https://JacksonBurns.github.io/ralf/)
